/**
 * Copyright Copyright 2007-8 Simon Andrews
 *
 *    This file is part of StackMeasure.
 *
 *    StackMeasure is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    StackMeasure is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with StackMeasure; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
public class StackMeasurePreferences {
	private int minIntensity;
	private int hueFlexibility;
	private double pixelDistance;
	private double stackDistance;
	private int minPixels;


	public StackMeasurePreferences () {
		// Set some defaults
		minIntensity = 20;
		hueFlexibility = 10;
		minPixels = 10;
		pixelDistance = 0.1;
		stackDistance = 0.3;
	}
	
	public int minIntensity () {
		return minIntensity;
	}
	public int hueFlexibility () {
		return hueFlexibility;
	}
	public double pixelDistance () {
		return pixelDistance;
	}
	public double stackDistance () {
		return stackDistance;
	}
	public int minPixels () {
		return minPixels;
	}
	
	public void setMinIntensity (int i) {
		if (i<0 || i>100) {
			throw new IllegalArgumentException("Intensity must be 1-100");
		}
		minIntensity = i;
	}
	public void setHueFlexibility (int i) {
		if (i<0 || i>100) {
			throw new IllegalArgumentException("Hue flexibility must be 1-100");
		}
		hueFlexibility = i;
	}
	public void setPixelDistance (double d) {
		if (d<0) {
			throw new IllegalArgumentException("Pixel distance must be positive");
		}

		pixelDistance = d;
	}
	public void setStackDistance (double d) {
		if (d<0) {
			throw new IllegalArgumentException("Stack distance must be positive");
		}
		stackDistance = d;
	}
	public void setMinPixels (int i) {
		if (i<1) {
			throw new IllegalArgumentException("Min pixels in group must be more than 1");
		}

		minPixels = i;
	}
	
}
